[hide private]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - turbogears.widgets.base.Widget: A TurboGears Widget.
    - turbogears.widgets.base.CompoundWidget: A widget that can contain other widgets.
      - turbogears.widgets.base.WidgetDescription: A description for a Widget.
        - turbofeeds.widgets.FeedLinksDesc
    - turbofeeds.widgets.FeedLinks: A list of links to feeds for all supported formats.
  - kid.BaseTemplate: Base class for compiled Templates.
    - turbofeeds.widgets.FeedLinksDesc.template_c
    - turbofeeds.widgets.FeedLinks.template_c
  - type: type(object) -> the object's type type(name, bases, dict) -> a new type
    - turbogears.widgets.meta.MetaWidget
      - turbogears.widgets.base.MetaDescription: Metaclass for widget descriptions.
  - turbogears.controllers.Controller: Base class for a web application's controller.
    - turbofeeds.controllers.FeedController: Controller for generating feeds in multiple formats.